@@ -1,8 +1,5 @@
 import os
 import random
-import torch
-import torch.backends.cudnn as cudnn
-from torch.autograd import Variable
 import numpy as np
 import scipy.sparse as sp 
 from sklearn.neighbors import NearestNeighbors, KNeighborsClassifier
